@@ -1,7 +1,7 @@
 # encoding: utf8
 ##############################################################################
 #
-#    Copyright (C) 2013 NaN Projectes de Programari Lliure, S.L.
+#    Copyright (C) 2013-2016 NaN Projectes de Programari Lliure, S.L.
 #                           http://www.NaN-tic.com
 #
 #    This program is free software: you can redistribute it and/or modify
@@ -19,8 +19,9 @@
 #
 ##############################################################################
 
-from record import Record
-from .fields import *
+from .exception import RetrofixException
+from .fields import Const, Char, Number, Integer, Numeric
+from .record import Record
 
 
 PRESENTER_HEADER_RECORD = (
@@ -32,7 +33,7 @@ PRESENTER_HEADER_RECORD = (
     ( 58,  1, 'support_type', Char),
     ( 59,  9, 'contact_phone', Number(align='right')),
     ( 68, 40, 'contact_name', Char),
-    (108, 13, 'declaration_number', Number(align='right')),
+    (108, 13, 'declaration_number', Integer),
     (121,  1, 'complementary', Char),
     (122,  1, 'replacement', Char),
     (123, 13, 'previous_declaration_number', Number(align='right')),
@@ -87,7 +88,7 @@ def read(data):
         if Record.valid(current_line, AMMENDMENT_RECORD):
             record = Record.extract(current_line, AMMENDMENT_RECORD)
         else:
-            raise Exception('Invalid record: %s' % current_line)
+            raise RetrofixException('Invalid record: %s' % current_line)
         records.append(record)
         current_line = lines.pop(0)
     return records
